@@ -1,12 +1,12 @@
-from openbox.acquisition_function import *
-from openbox.surrogate.base.rf_with_instances import RandomForestWithInstances
-from openbox.surrogate.base.build_gp import create_gp_model
-from openbox.utils.util_funcs import get_types
-from openbox.utils.constants import MAXINT
 from collections import namedtuple
+from openbox.utils.constants import MAXINT
+from openbox.acquisition_function import *
+from openbox.utils.util_funcs import get_types
+
 
 Observation = namedtuple('Observation', ['config', 'trial_state', 'constraints', 'objs', 'elapsed_time'])
 
+
 acq_dict = {
     'ei': EI,
     'eips': EIPS,
@@ -78,14 +78,36 @@ def build_optimizer(func_str='local_random', acq_func=None, config_space=None, r
                      rng=rng)
 
 
-def build_surrogate(func_str='prf', config_space=None, rng=None, history_hpo_data=None):
+def build_surrogate(func_str='gp', config_space=None, rng=None, history_hpo_data=None):
     assert config_space is not None
     func_str = func_str.lower()
     types, bounds = get_types(config_space)
     seed = rng.randint(MAXINT)
     if func_str == 'prf':
-        return RandomForestWithInstances(types=types, bounds=bounds, seed=seed)
+        try:
+            from openbox.surrogate.base.rf_with_instances import RandomForestWithInstances
+            return RandomForestWithInstances(types=types, bounds=bounds, seed=seed)
+        except ModuleNotFoundError:
+            from openbox.surrogate.base.rf_with_instances_sklearn import skRandomForestWithInstances
+            print('[Build Surrogate] Use probabilistic random forest based on scikit-learn. For better performance, '
+                  'please install pyrfr: '
+                  'https://open-box.readthedocs.io/en/latest/installation/install_pyrfr.html')
+            return skRandomForestWithInstances(types=types, bounds=bounds, seed=seed)
+
+    elif func_str == 'sk_prf':
+        from openbox.surrogate.base.rf_with_instances_sklearn import skRandomForestWithInstances
+        return skRandomForestWithInstances(types=types, bounds=bounds, seed=seed)
+
+    elif func_str == 'lightgbm':
+        from openbox.surrogate.lightgbm import LightGBM
+        return LightGBM(config_space, types=types, bounds=bounds, seed=seed)
+
+    if func_str == 'random_forest':
+        from openbox.surrogate.skrf import RandomForestSurrogate
+        return RandomForestSurrogate(config_space, types=types, bounds=bounds, seed=seed)
+
     elif func_str.startswith('gp'):
+        from openbox.surrogate.base.build_gp import create_gp_model
         return create_gp_model(model_type=func_str,
                                config_space=config_space,
                                types=types,
