@@ -4,14 +4,13 @@ import time
 import numpy as np
 from typing import List
 from collections import OrderedDict
-from tensorboardX import SummaryWriter
 from openbox.utils.logging_utils import setup_logger, get_logger
 
 
 class BOBase(object, metaclass=abc.ABCMeta):
     def __init__(self, objective_function, config_space, task_id='task_id', output_dir='logs/',
                  random_state=1, initial_runs=3, max_runs=50, runtime_limit=None,
-                 sample_strategy='bo', surrogate_type='prf',
+                 sample_strategy='bo', surrogate_type='gp',
                  history_bo_data: List[OrderedDict] = None,
                  time_limit_per_trial=600):
         self.output_dir = output_dir
@@ -24,7 +23,6 @@ class BOBase(object, metaclass=abc.ABCMeta):
         self.logger_name = None
         self.logger = self._get_logger(_logger_id)
         self.rng = np.random.RandomState(random_state)
-        self.writer = SummaryWriter(log_dir='logs/%s' % task_id)
 
         self.config_space = config_space
         self.objective_function = objective_function
